==> jc-1.4.0.tar.gz: polyglot/util/Enum.h <==
// public class polyglot.util.Enum

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 82f09079602e8c27 polyglot_util_Enum

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_Enum_H_
#define _JC_polyglot_util_Enum_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_polyglot_util_Enum$object;

// Typedefs
typedef struct _jc_polyglot_util_Enum$sub_refs	_jc_polyglot_util_Enum$sub_refs;
typedef struct _jc_polyglot_util_Enum$sub_nonrefs	_jc_polyglot_util_Enum$sub_nonrefs;
typedef struct _jc_polyglot_util_Enum$refs	_jc_polyglot_util_Enum$refs;
typedef struct _jc_polyglot_util_Enum$nonrefs	_jc_polyglot_util_Enum$nonrefs;
typedef struct _jc_polyglot_util_Enum$object	_jc_polyglot_util_Enum$object;

typedef struct _jc_polyglot_util_Enum$fields_struct	_jc_polyglot_util_Enum$fields_struct;
typedef const struct _jc_polyglot_util_Enum$vmethods	_jc_polyglot_util_Enum$vmethods;
typedef const struct _jc_polyglot_util_Enum$vtable	_jc_polyglot_util_Enum$vtable;
typedef const struct _jc_polyglot_util_Enum$vtype	_jc_polyglot_util_Enum$vtype;

// Class fields structure
struct _jc_polyglot_util_Enum$fields_struct {
	struct _jc_object	*cache;
};
extern _jc_polyglot_util_Enum$fields_struct _jc_polyglot_util_Enum$class_fields;

// Constructors
extern void _jc_polyglot_util_Enum$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_Enum$object *);
extern void _jc_polyglot_util_Enum$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_util_Enum$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_polyglot_util_Enum$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_util_Enum$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_polyglot_util_Enum$object *_jc_polyglot_util_Enum$method$intern$50b920faa861ae4f(_jc_env *, struct _jc_polyglot_util_Enum$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_util_Enum$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_util_Enum$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_Enum$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_util_Enum$method_info$intern$50b920faa861ae4f;
extern _jc_method _jc_polyglot_util_Enum$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_polyglot_util_Enum$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_String$object *_jc_polyglot_util_Enum$method$access__24000$27f3c3f0aed94a9b(_jc_env *, struct _jc_polyglot_util_Enum$object *);

// Virtual methods structure
struct _jc_polyglot_util_Enum$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_util_Enum$object *, struct _jc_java_lang_Object$object *);
	struct _jc_polyglot_util_Enum$object	*(*intern$50b920faa861ae4f)(_jc_env *, struct _jc_polyglot_util_Enum$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_util_Enum$object *);
};

// Vtable
struct _jc_polyglot_util_Enum$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Enum$vmethods	polyglot_util_Enum;
};

// Vtype
struct _jc_polyglot_util_Enum$vtype {
	_jc_type			type;
	_jc_polyglot_util_Enum$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_Enum$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_polyglot_util_Enum$refs {
    _jc_polyglot_util_Enum$sub_refs	polyglot_util_Enum;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_Enum$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_Enum$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Enum$sub_nonrefs	polyglot_util_Enum;
};

// Object instance structure
struct _jc_polyglot_util_Enum$object {
	_jc_polyglot_util_Enum$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_Enum$vtype	*vtype;
	_jc_polyglot_util_Enum$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_Enum$vtype _jc_polyglot_util_Enum$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_Enum, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_Enum$class_object;

#endif	/* _JC_polyglot_util_Enum_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/Enum.h <==
// public class polyglot.util.Enum

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 82f09079602e8c27 polyglot_util_Enum

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_Enum_H_
#define _JC_polyglot_util_Enum_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_polyglot_util_Enum$object;

// Typedefs
typedef struct _jc_polyglot_util_Enum$sub_refs	_jc_polyglot_util_Enum$sub_refs;
typedef struct _jc_polyglot_util_Enum$sub_nonrefs	_jc_polyglot_util_Enum$sub_nonrefs;
typedef struct _jc_polyglot_util_Enum$refs	_jc_polyglot_util_Enum$refs;
typedef struct _jc_polyglot_util_Enum$nonrefs	_jc_polyglot_util_Enum$nonrefs;
typedef struct _jc_polyglot_util_Enum$object	_jc_polyglot_util_Enum$object;

typedef struct _jc_polyglot_util_Enum$fields_struct	_jc_polyglot_util_Enum$fields_struct;
typedef const struct _jc_polyglot_util_Enum$vmethods	_jc_polyglot_util_Enum$vmethods;
typedef const struct _jc_polyglot_util_Enum$vtable	_jc_polyglot_util_Enum$vtable;
typedef const struct _jc_polyglot_util_Enum$vtype	_jc_polyglot_util_Enum$vtype;

// Class fields structure
struct _jc_polyglot_util_Enum$fields_struct {
	struct _jc_object	*cache;
};
extern _jc_polyglot_util_Enum$fields_struct _jc_polyglot_util_Enum$class_fields;

// Constructors
extern void _jc_polyglot_util_Enum$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_Enum$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_Enum$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_util_Enum$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_util_Enum$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_util_Enum$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_util_Enum$object *_jc_polyglot_util_Enum$method$intern$50b920faa861ae4f(_jc_env *, struct _jc_polyglot_util_Enum$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_util_Enum$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_util_Enum$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_Enum$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_util_Enum$method_info$intern$50b920faa861ae4f;
extern _jc_method _jc_polyglot_util_Enum$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_polyglot_util_Enum$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_util_Enum$method$access__24000$27f3c3f0aed94a9b(_jc_env *, struct _jc_polyglot_util_Enum$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_util_Enum$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_util_Enum$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_util_Enum$object	*(*intern$50b920faa861ae4f)(_jc_env *, struct _jc_polyglot_util_Enum$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_util_Enum$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_Enum$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Enum$vmethods	polyglot_util_Enum;
};

// Vtype
struct _jc_polyglot_util_Enum$vtype {
	_jc_type			type;
	_jc_polyglot_util_Enum$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_Enum$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_polyglot_util_Enum$refs {
    _jc_polyglot_util_Enum$sub_refs	polyglot_util_Enum;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_Enum$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_Enum$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Enum$sub_nonrefs	polyglot_util_Enum;
};

// Object instance structure
struct _jc_polyglot_util_Enum$object {
	_jc_polyglot_util_Enum$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_Enum$vtype	*vtype;
	_jc_polyglot_util_Enum$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_Enum$vtype _jc_polyglot_util_Enum$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_Enum, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_Enum$class_object;

#endif	/* _JC_polyglot_util_Enum_H_ */
